# Pyonir Web Framework

A static website generator and flat file web framework written in Python.

# Install

From the pypi:

`pip install pyonir`

From the github:

`pip install pyonir` 

# Generate Static Site

# Configure Content

# Configure Frontend

# Configure Plugins

# Configure Static Assets

# Configure Server Controllers

# Run Server